@@ -59,6 +59,13 @@ class Command(BaseCommand):
             cmd = "python manage.py build_templates \"%s\" \"%s\" -o" % (
                     templateDir, dstPath)
             run(cmd, env=env, shell=True)
+            with open(os.path.join(machinePath, 'BuildTemplates.log')) as log:
+                content = log.read()
+            if content:
+                logger.error(content)
+                return 1
+            else:
+                return 0
         finally:
             # remove project
             os.chdir(currentPath)
